@@ -215,8 +215,6 @@ def build_app(
     url,
     host=None,
     reaper_on=True,
-    hide_shutdown=False,
-    github_fork=False,
     app_root=None,
 ):
     """
@@ -235,8 +233,6 @@ def build_app(
         app_root=app_root,
     )
     app.config["SECRET_KEY"] = "Dtale"
-    app.config["HIDE_SHUTDOWN"] = hide_shutdown
-    app.config["GITHUB_FORK"] = github_fork
 
     app.jinja_env.trim_blocks = True
     app.jinja_env.lstrip_blocks = True
@@ -533,6 +529,11 @@ def show(
     context_vars=None,
     ignore_duplicate=False,
     app_root=None,
+    allow_cell_edits=True,
+    inplace=False,
+    drop_index=False,
+    hide_shutdown=False,
+    github_fork=False,
     **kwargs
 ):
     """
@@ -569,6 +570,22 @@ def show(
     :param ignore_duplicate: if true, this will not check if this data matches any other data previously loaded to
                              D-Tale
     :type ignore_duplicate: bool, optional
+    :param app_root: Optional path to prepend to the routes of D-Tale. This is used when making use of
+                     Jupyterhub server proxy
+    :type app_root: str, optional
+    :param allow_cell_edits: If false, this will not allow users to edit cells directly in their D-Tale grid
+    :type allow_cell_edits: bool, optional
+    :param inplace: If true, this will call `reset_index(inplace=True)` on the dataframe used as a way to save memory.
+                    Otherwise this will create a brand new dataframe, thus doubling memory but leaving the dataframe
+                    input unchanged.
+    :type inplace: bool, optional
+    :param drop_index: If true, this will drop any pre-existing index on the dataframe input.
+    :type drop_index: bool, optional
+    :param hide_shutdown: If true, this will hide the "Shutdown" buton from users
+    :type hide_shutdown: bool, optional
+    :param github_fork: If true, this will display a "Fork me on GitHub" ribbon in the upper right-hand corner of the
+                        app
+    :type github_fork: bool, optional
 
     :Example:
 
@@ -610,6 +627,11 @@ def show(
             name=name,
             context_vars=context_vars,
             ignore_duplicate=ignore_duplicate,
+            allow_cell_edits=allow_cell_edits,
+            inplace=inplace,
+            drop_index=drop_index,
+            hide_shutdown=hide_shutdown,
+            github_fork=github_fork,
         )
         is_active = not running_with_flask_debug() and is_up(app_url)
         if is_active:
@@ -740,6 +762,7 @@ def offline_chart(
     barsort=None,
     yaxis=None,
     filepath=None,
+    title=None,
     **kwargs
 ):
     """
@@ -773,6 +796,8 @@ def offline_chart(
     :type barsort: str, optional
     :param filepath: location to save HTML output
     :type filepath: str, optional
+    :param title: Title of your chart
+    :type title: str, optional
     :param kwargs: optional keyword arguments, here in case invalid arguments are passed to this function
     :type kwargs: dict
     :return: possible outcomes are:
@@ -796,6 +821,7 @@ def offline_chart(
         barsort=barsort,
         yaxis=yaxis,
         filepath=filepath,
+        title=title,
         **kwargs
     )
     global_state.cleanup()
