@@ -14,6 +14,7 @@ from dtale.utils import (
     json_int,
     make_list,
     run_query,
+    triple_quote,
 )
 
 YAXIS_CHARTS = ["line", "bar", "scatter"]
@@ -67,6 +68,14 @@ def valid_chart(chart_type=None, x=None, y=None, z=None, **inputs):
             return True
         return False
 
+    if chart_type == "candlestick":
+        cs_props = ["cs_x", "cs_open", "cs_close", "cs_high", "cs_low"]
+        return all(inputs.get(p) is not None for p in cs_props)
+
+    if chart_type == "treemap":
+        treemap_props = ["treemap_value", "treemap_label"]
+        return all(inputs.get(p) is not None for p in treemap_props)
+
     if x is None or not len(y or []):
         return False
 
@@ -142,6 +151,12 @@ def date_freq_handler(df):
     return _handler
 
 
+def convert_date_val_to_date(group_val):
+    if isinstance(group_val, int):
+        return pd.Timestamp(group_val, unit="ms")
+    return pd.Timestamp(group_val)
+
+
 def group_filter_handler(col_def, group_val, group_classifier):
     col_def_segs = col_def.split("|")
     if len(col_def_segs) > 1:
@@ -158,32 +173,34 @@ def group_filter_handler(col_def, group_val, group_classifier):
                 col=col, day=ts_val.strftime("%Y%m%d"), hour=ts_val.hour
             )
         elif freq == "D":
-            ts_val = pd.Timestamp(group_val)
+            ts_val = convert_date_val_to_date(group_val)
             return "{col}.dt.date == '{day}'".format(
                 col=col, day=ts_val.strftime("%Y%m%d")
             )
         elif freq == "W":
-            ts_val = pd.Timestamp(group_val)
+            ts_val = convert_date_val_to_date(group_val)
             return "{col}.dt.year == {year} and {col}.dt.week == {week}".format(
                 col=col, year=ts_val.year, week=ts_val.week
             )
         elif freq == "M":
-            ts_val = pd.Timestamp(group_val)
+            ts_val = convert_date_val_to_date(group_val)
             return "{col}.dt.year == {year} and {col}.dt.month == {month}".format(
                 col=col, year=ts_val.year, month=ts_val.month
             )
         elif freq == "Q":
-            ts_val = pd.Timestamp(group_val)
+            ts_val = convert_date_val_to_date(group_val)
             return "{col}.dt.year == {year} and {col}.dt.quarter == {quarter}".format(
                 col=col, year=ts_val.year, quarter=ts_val.quarter
             )
         elif freq == "Y":
-            ts_val = pd.Timestamp(group_val)
+            ts_val = convert_date_val_to_date(group_val)
             return "{col}.dt.year == {year}".format(col=col, year=ts_val.year)
     if group_val == "nan":
         return "{col} != {col}".format(col=col_def)
     if group_classifier in ["I", "F"]:
         return "{col} == {val}".format(col=col_def, val=group_val)
+    if group_classifier == "D":
+        group_val = convert_date_val_to_date(group_val).strftime("%Y%m%d")
     return "{col} == '{val}'".format(col=col_def, val=group_val)
 
 
@@ -231,7 +248,9 @@ def retrieve_chart_data(df, *args, **kwargs):
     if len(make_list(kwargs.get("group_val"))):
         filters = build_group_inputs_filter(all_data, kwargs["group_val"])
         all_data = run_query(all_data, filters)
-        all_code.append("chart_data = chart_data.query({})".format(filters))
+        all_code.append(
+            "chart_data = chart_data.query({})".format(triple_quote(filters))
+        )
     return all_data, all_code
 
 
@@ -339,7 +358,7 @@ def build_agg_data(df, x, y, inputs, agg, z=None, group_col=None, animate_by=Non
         return agg_df, code
 
     idx_cols = make_list(animate_by) + make_list(group_col) + [x]
-    agg_cols = y
+    agg_cols = make_list(y)
     if z_exists:
         idx_cols += make_list(y)
         agg_cols = make_list(z)
@@ -362,7 +381,7 @@ def build_agg_data(df, x, y, inputs, agg, z=None, group_col=None, animate_by=Non
         code = code.format(
             cols="', '".join(idx_cols),
             subidx_cols="', '".join(subidx_cols),
-            agg_cols="', '".join(agg_cols),
+            agg_cols="', '".join(make_list(agg_cols)),
             agg=func,
         )
         code = [code]
