@@ -24,6 +24,19 @@ logger = getLogger(__name__)
     help="flag to automatically open default web browser on startup",
 )
 @click.option("--name", type=str, help="name to apply to your D-Tale session")
+@click.option(
+    "--no-cell-edits",
+    is_flag=True,
+    help="flag to turn off auto-reaping (process cleanup after period of inactivity",
+)
+@click.option(
+    "--hide-shutdown", is_flag=True, help='flag to hide "Shutdown" button from users'
+)
+@click.option(
+    "--github-fork",
+    is_flag=True,
+    help='flag to show "Fork Me On GitHub" link in upper right-hand corner of the app',
+)
 @setup_loader_options()
 @click.option("--log", "logfile", help="Log file name")
 @click.option(
@@ -41,6 +54,9 @@ def main(
     no_reaper=False,
     open_browser=False,
     name=None,
+    no_cell_edits=False,
+    hide_shutdown=False,
+    github_fork=False,
     **kwargs
 ):
     """
@@ -65,6 +81,9 @@ def main(
         reaper_on=not no_reaper,
         open_browser=open_browser,
         name=name,
+        allow_cell_edits=not no_cell_edits,
+        hide_shutdown=hide_shutdown,
+        github_fork=github_fork,
         **kwargs
     )
 
