@@ -5,6 +5,7 @@ import time
 import numpy as np
 import pandas as pd
 from scipy.stats import mstats
+from six import string_types
 
 import dtale.global_state as global_state
 from dtale.utils import classify_type
@@ -15,6 +16,8 @@ class ColumnBuilder(object):
         self.data_id = data_id
         if column_type == "numeric":
             self.builder = NumericColumnBuilder(name, cfg)
+        elif column_type == "string":
+            self.builder = StringColumnBuilder(name, cfg)
         elif column_type == "datetime":
             self.builder = DatetimeColumnBuilder(name, cfg)
         elif column_type == "bins":
@@ -27,6 +30,8 @@ class ColumnBuilder(object):
             self.builder = TransformColumnBuilder(name, cfg)
         elif column_type == "winsorize":
             self.builder = WinsorizeColumnBuilder(name, cfg)
+        elif column_type == "zscore_normalize":
+            self.builder = ZScoreNormalizeColumnBuilder(name, cfg)
         else:
             raise NotImplementedError(
                 "'{}' column builder not implemented yet!".format(column_type)
@@ -74,6 +79,31 @@ class NumericColumnBuilder(object):
         )
 
 
+class StringColumnBuilder(object):
+    def __init__(self, name, cfg):
+        self.name = name
+        self.cfg = cfg
+
+    def build_column(self, data):
+        cols, join_char = (self.cfg.get(p) for p in ["cols", "joinChar"])
+        return pd.Series(
+            data[cols].astype("str").agg(join_char.join, axis=1),
+            index=data.index,
+            name=self.name,
+        )
+
+    def build_code(self):
+        cols, join_char = (self.cfg.get(p) for p in ["cols", "joinChar"])
+        data_str = (
+            "data[['{cols}']].astype('str').agg('{join_char}'.join, axis=1)".format(
+                cols="', '".join(cols), join_char=join_char
+            )
+        )
+        return (
+            "df.loc[:, '{name}'] = pd.Series({data_str}, index=df.index, name='{name}')"
+        ).format(name=self.name, data_str=data_str)
+
+
 FREQ_MAPPING = dict(month="M", quarter="Q", year="Y")
 
 
@@ -133,6 +163,22 @@ class BinsColumnBuilder(object):
             cats = {idx: str(cat) for idx, cat in enumerate(bin_data.cat.categories)}
         return pd.Series(bin_data.cat.codes.map(cats), index=data.index, name=self.name)
 
+    def build_test(self, data):
+        col, operation, bins, labels = (
+            self.cfg.get(p) for p in ["col", "operation", "bins", "labels"]
+        )
+        bins = int(bins)
+        if operation == "cut":
+            bin_data = pd.cut(data[col], bins=bins)
+        else:
+            bin_data = pd.qcut(data[col], q=bins)
+        counts = [int(c) for c in bin_data.groupby(bin_data.cat.codes).count().values]
+        if labels:
+            labels = labels.split(",")
+        else:
+            labels = list(map(str, bin_data.cat.categories))
+        return counts, labels
+
     def build_code(self):
         col, operation, bins, labels = (
             self.cfg.get(p) for p in ["col", "operation", "bins", "labels"]
@@ -349,14 +395,41 @@ class TypeConversionColumnBuilder(object):
                 return pd.Series(
                     s.astype("float").astype("int"), name=self.name, index=s.index
                 )
+            elif to_type == "float":
+                return pd.Series(
+                    pd.to_numeric(s, errors="coerce"), name=self.name, index=s.index
+                )
             else:
+                if from_type.startswith("mixed"):
+                    if to_type == "float":
+                        return pd.Series(
+                            pd.to_numeric(s, errors="coerce"),
+                            name=self.name,
+                            index=s.index,
+                        )
+                    elif to_type == "bool":
+
+                        def _process_mixed_bool(v):
+                            if isinstance(v, bool):
+                                return v
+                            if isinstance(v, string_types):
+                                return dict(true=True, false=False).get(
+                                    v.lower(), np.nan
+                                )
+                            return np.nan
+
+                        return pd.Series(
+                            s.apply(_process_mixed_bool), name=self.name, index=s.index
+                        )
                 return pd.Series(s.astype(to_type), name=self.name, index=s.index)
         elif classifier == "I":  # date, float, category, str, bool
             if to_type == "date":
                 unit = self.cfg.get("unit") or "D"
                 if unit == "YYYYMMDD":
                     return pd.Series(
-                        s.astype(str).apply(pd.Timestamp), name=self.name, index=s.index
+                        s.astype("str").apply(pd.Timestamp),
+                        name=self.name,
+                        index=s.index,
                     )
                 return pd.Series(
                     pd.to_datetime(s, unit=unit), name=self.name, index=s.index
@@ -403,7 +476,27 @@ class TypeConversionColumnBuilder(object):
                 return "pd.Series({s}.astype('float').astype('int'), name='{name}', index={s}.index)".format(
                     s=s, name=self.name
                 )
+            elif to_type == "float":
+                return "pd.Series(pd.to_numeric({s}, errors='coerce'), name='{name}', index={s}.index)".format(
+                    s=s, name=self.name
+                )
             else:
+                if from_type.startswith("mixed"):
+                    if to_type == "float":
+                        return "pd.Series(pd.to_numeric({s}, errors='coerce'), name='{name}', index={s}.index)".format(
+                            s=s, name=self.name
+                        )
+                    elif to_type == "bool":
+                        return (
+                            "def _process_mixed_bool(v):\n"
+                            "from six import string_types\n\n"
+                            "\tif isinstance(v, bool):\n"
+                            "\t\treturn v\n"
+                            "\tif isinstance(v, string_types):\n"
+                            "\t\treturn dict(true=True, false=False).get(v.lower(), np.nan)\n"
+                            "\treturn np.nan\n\n"
+                            "pd.Series({s}.apply(_process_mixed_bool), name='{name}', index={s}.index)"
+                        ).format(s=s, name=self.name)
                 return "pd.Series({s}.astype({to_type}), name='{name}', index={s}.index)".format(
                     s=s, to_type=to_type, name=self.name
                 )
@@ -412,7 +505,8 @@ class TypeConversionColumnBuilder(object):
                 unit = self.cfg.get("unit") or "D"
                 if unit == "YYYYMMDD":
                     return "pd.Series({s}.astype(str).apply(pd.Timestamp), name='{name}', index={s}.index)".format(
-                        s=s, name=self.name,
+                        s=s,
+                        name=self.name,
                     )
                 return "pd.Series(pd.to_datetime({s}, unit='{unit}'), name='{name}', index={s}.index)".format(
                     s=s, name=self.name, unit=unit
@@ -466,9 +560,12 @@ class TransformColumnBuilder(object):
 
     def build_code(self):
         group, col, agg = (self.cfg.get(p) for p in ["group", "col", "agg"])
-        return (
-            "pd.Series(data.groupby(['{group}'])['{col}'].transform('{agg}'), index=data.index, name='{name}')"
+        code = (
+            "pd.Series(\n"
+            "\tdata.groupby(['{group}'])['{col}'].transform('{agg}'), index=data.index, name='{name}'\n"
+            ")"
         ).format(name=self.name, col=col, agg=agg, group="','".join(group))
+        return "df.loc[:, '{name}'] = {code}".format(name=self.name, code=code)
 
 
 class WinsorizeColumnBuilder(object):
@@ -511,21 +608,49 @@ class WinsorizeColumnBuilder(object):
         else:
             winsorize_params = ""
         if len(group or []):
-            return (
+            code = (
                 "from scipy.stats import mstats\n\n"
                 "def winsorize_series(group):\n"
                 "\treturn mstats.winsorize(group{params})\n\n"
                 "winsorized_data = data.groupby(['{group}'])['{col}'].transform(winsorize_series)\n"
-                "pd.Series(winsorized_data, index=data.index, name='{name}')"
+                "winsorized_data = pd.Series(winsorized_data, index=data.index, name='{name}')"
             ).format(
                 params=winsorize_params,
                 col=col,
                 group="', '".join(group),
                 name=self.name,
             )
+        else:
+            code = (
+                "from scipy.stats import mstats\n\n"
+                "winsorized_data = mstats.winsorize(data['{col}']{params})\n"
+                "winsorized_data = pd.Series(winsorized_data, index=data.index, name='{name}')"
+            ).format(params=winsorize_params, col=col, name=self.name)
+        return [code, "df.loc[:, '{name}'] = winsorized_data".format(name=self.name)]
 
+
+ZERO_STD_ERROR = "Column consists of a constant value and z-score normalization will result in all nans!"
+
+
+class ZScoreNormalizeColumnBuilder(object):
+    def __init__(self, name, cfg):
+        self.name = name
+        self.cfg = cfg
+
+    def build_column(self, data):
+        col = self.cfg.get("col")
+        if data[col].std() == 0:
+            raise Exception(ZERO_STD_ERROR)
+        return pd.Series(
+            (data[col] - data[col].mean()) / data[col].std(ddof=0),
+            index=data.index,
+            name=self.name,
+        )
+
+    def build_code(self):
+        col = self.cfg.get("col")
         return (
-            "from scipy.stats import mstats\n\n"
-            "winsorized_data = mstats.winsorize(data['{col}']{params})\n"
-            "pd.Series(winsorized_data, index=data.index, name='{name}')"
-        ).format(params=winsorize_params, col=col, name=self.name)
+            "df.loc[:, '{name}'] = pd.Series(\n"
+            "\t(data['{col}'] - data['{col}'].mean()) / data['{col}'].std(ddof=0), index=data.index, name='{name}'\n"
+            ")"
+        ).format(name=self.name, col=col)
