@@ -8,9 +8,15 @@ from dash.dependencies import Input, Output, State
 from dash.exceptions import PreventUpdate
 
 import dtale.dash_application.custom_geojson as custom_geojson
+import dtale.dash_application.drilldown_modal as drilldown_modal
+import dtale.dash_application.lock_zoom as lock_zoom
 import dtale.global_state as global_state
 from dtale.charts.utils import MAX_GROUPS, ZAXIS_CHARTS
-from dtale.dash_application.charts import build_chart, chart_url_params
+from dtale.dash_application.charts import (
+    build_chart,
+    chart_url_params,
+    CHART_EXPORT_CODE,
+)
 from dtale.dash_application.layout.layout import (
     animate_styles,
     bar_input_style,
@@ -19,17 +25,22 @@ from dtale.dash_application.layout.layout import (
     build_input_options,
     build_loc_mode_hover_children,
     build_map_options,
+    build_candlestick_options,
     build_mapbox_style_options,
     build_proj_hover_children,
+    build_treemap_options,
     charts_layout,
     colorscale_input_style,
     get_yaxis_type_tabs,
+    lock_zoom_style,
     main_inputs_and_group_val_display,
     show_chart_per_group,
     show_group_input,
     show_input_handler,
     show_yaxis_ranges,
 )
+from dtale.dash_application.layout.utils import show_style
+from dtale.dash_application.utils import get_data_id
 from dtale.utils import dict_merge, is_app_root_defined, make_list, run_query
 
 logger = getLogger(__name__)
@@ -43,9 +54,11 @@ class DtaleDash(dash.Dash):
 
     def __init__(self, *args, **kwargs):
         server = kwargs.get("server")
-        kwargs["external_stylesheets"] = ["/css/main.css", "/css/dash.css"]
-        if server.config["GITHUB_FORK"]:
-            kwargs["external_stylesheets"].append("/css/github_fork.css")
+        kwargs["external_stylesheets"] = [
+            "/css/main.css",
+            "/css/dash.css",
+            "/css/github_fork.css",
+        ]
         kwargs["external_scripts"] = [
             "/dash/components_bundle.js",
             "/dash/custom_bundle.js",
@@ -73,11 +86,8 @@ class DtaleDash(dash.Dash):
         super(DtaleDash, self).__init__(*args, **kwargs)
 
     def interpolate_index(self, **kwargs):
-        return base_layout(
-            self.server.config["GITHUB_FORK"],
-            self.server.config.get("APPLICATION_ROOT"),
-            **kwargs
-        )
+        print(kwargs)
+        return base_layout(self.server.config.get("APPLICATION_ROOT"), **kwargs)
 
 
 def add_dash(server):
@@ -111,13 +121,6 @@ def add_dash(server):
     return dash_app.server
 
 
-def get_data_id(pathname):
-    """
-    Parses data ID from query path (ex: 'foo/bar/1' => '1')
-    """
-    return global_state.find_data_id(pathname.split("/")[-1])
-
-
 def init_callbacks(dash_app):
     """
     Dynamically adds dash callbacks to dash-wrapped flask server
@@ -174,9 +177,13 @@ def init_callbacks(dash_app):
             Output("group-dropdown", "options"),
             Output("barsort-dropdown", "options"),
             Output("yaxis-dropdown", "options"),
-            Output("non-map-inputs", "style"),
+            Output("standard-inputs", "style"),
             Output("map-inputs", "style"),
+            Output("candlestick-inputs", "style"),
+            Output("treemap-inputs", "style"),
             Output("colorscale-input", "style"),
+            Output("drilldown-input", "style"),
+            Output("lock-zoom-btn", "style"),
         ],
         [
             Input("query-data", "modified_timestamp"),
@@ -240,8 +247,15 @@ def init_callbacks(dash_app):
         ) = options
         show_map = chart_type == "maps"
         map_style = {} if show_map else {"display": "none"}
-        non_map_style = {"display": "none"} if show_map else {}
+        show_cs = chart_type == "candlestick"
+        cs_style = {} if show_cs else {"display": "none"}
+        show_treemap = chart_type == "treemap"
+        treemap_style = {} if show_treemap else {"display": "none"}
+        standard_style = (
+            {"display": "none"} if show_map or show_cs or show_treemap else {}
+        )
         cscale_style = colorscale_input_style(chart_type=chart_type)
+        drilldown_toggle_style = show_style((agg or "raw") != "raw")
         return (
             inputs,
             x_options,
@@ -251,9 +265,13 @@ def init_callbacks(dash_app):
             group_options,
             barsort_options,
             yaxis_options,
-            non_map_style,
+            standard_style,
             map_style,
+            cs_style,
+            treemap_style,
             cscale_style,
+            drilldown_toggle_style,
+            lock_zoom_style(chart_type),
         )
 
     @dash_app.callback(
@@ -386,6 +404,103 @@ def init_callbacks(dash_app):
             set_mapbox_token(token)
         return build_mapbox_style_options()
 
+    @dash_app.callback(
+        [
+            Output("candlestick-input-data", "data"),
+            Output("candlestick-x-dropdown", "options"),
+            Output("candlestick-open-dropdown", "options"),
+            Output("candlestick-close-dropdown", "options"),
+            Output("candlestick-high-dropdown", "options"),
+            Output("candlestick-low-dropdown", "options"),
+        ],
+        [
+            Input("candlestick-x-dropdown", "value"),
+            Input("candlestick-open-dropdown", "value"),
+            Input("candlestick-close-dropdown", "value"),
+            Input("candlestick-high-dropdown", "value"),
+            Input("candlestick-low-dropdown", "value"),
+            Input("candlestick-group-dropdown", "value"),
+        ],
+        [State("url", "pathname")],
+    )
+    def cs_data_callback(
+        cs_x,
+        cs_open,
+        cs_close,
+        cs_high,
+        cs_low,
+        group,
+        pathname,
+    ):
+        data_id = get_data_id(pathname)
+        cs_data = dict(
+            cs_x=cs_x,
+            cs_open=cs_open,
+            cs_close=cs_close,
+            cs_high=cs_high,
+            cs_low=cs_low,
+        )
+        if group is not None:
+            cs_data["cs_group"] = group
+        df = global_state.get_data(data_id)
+        (
+            x_options,
+            close_options,
+            open_options,
+            low_options,
+            high_options,
+        ) = build_candlestick_options(
+            df,
+            cs_x=cs_x,
+            cs_open=cs_open,
+            cs_close=cs_close,
+            cs_high=cs_high,
+            cs_low=cs_low,
+        )
+
+        return (
+            cs_data,
+            x_options,
+            open_options,
+            close_options,
+            high_options,
+            low_options,
+        )
+
+    @dash_app.callback(
+        [
+            Output("treemap-input-data", "data"),
+            Output("treemap-value-dropdown", "options"),
+            Output("treemap-label-dropdown", "options"),
+        ],
+        [
+            Input("treemap-value-dropdown", "value"),
+            Input("treemap-label-dropdown", "value"),
+            Input("treemap-group-dropdown", "value"),
+        ],
+        [State("url", "pathname")],
+    )
+    def treemap_data_callback(
+        treemap_value,
+        treemap_label,
+        group,
+        pathname,
+    ):
+        data_id = get_data_id(pathname)
+        treemap_data = dict(
+            treemap_value=treemap_value,
+            treemap_label=treemap_label,
+        )
+        if group is not None:
+            treemap_data["treemap_group"] = group
+        df = global_state.get_data(data_id)
+        value_options, label_options = build_treemap_options(
+            df,
+            treemap_value=treemap_value,
+            treemap_label=treemap_label,
+        )
+        return treemap_data, value_options, label_options
+
     @dash_app.callback(
         [
             Output("y-multi-input", "style"),
@@ -492,6 +607,8 @@ def init_callbacks(dash_app):
             Input("chart-input-data", "modified_timestamp"),
             Input("yaxis-data", "modified_timestamp"),
             Input("map-input-data", "modified_timestamp"),
+            Input("candlestick-input-data", "modified_timestamp"),
+            Input("treemap-input-data", "modified_timestamp"),
         ],
         [
             State("url", "pathname"),
@@ -499,6 +616,8 @@ def init_callbacks(dash_app):
             State("chart-input-data", "data"),
             State("yaxis-data", "data"),
             State("map-input-data", "data"),
+            State("candlestick-input-data", "data"),
+            State("treemap-input-data", "data"),
             State("last-chart-input-data", "data"),
         ],
     )
@@ -507,18 +626,27 @@ def init_callbacks(dash_app):
         _ts2,
         _ts3,
         _ts4,
+        _ts5,
+        _ts6,
         pathname,
         inputs,
         chart_inputs,
         yaxis_data,
         map_data,
+        cs_data,
+        treemap_data,
         last_chart_inputs,
     ):
         """
         dash callback controlling the building of dash charts
         """
         all_inputs = dict_merge(
-            inputs, chart_inputs, dict(yaxis=yaxis_data or {}), map_data
+            inputs,
+            chart_inputs,
+            dict(yaxis=yaxis_data or {}),
+            map_data,
+            cs_data,
+            treemap_data,
         )
         if all_inputs == last_chart_inputs:
             raise PreventUpdate
@@ -529,7 +657,7 @@ def init_callbacks(dash_app):
             charts,
             all_inputs,
             range_data,
-            "\n".join(make_list(code)),
+            "\n".join(make_list(code) + [CHART_EXPORT_CODE]),
             get_yaxis_type_tabs(make_list(inputs.get("y") or [])),
         )
 
@@ -659,11 +787,22 @@ def init_callbacks(dash_app):
         [
             Input("input-data", "modified_timestamp"),
             Input("map-input-data", "modified_timestamp"),
+            Input("candlestick-input-data", "modified_timestamp"),
+            Input("treemap-input-data", "modified_timestamp"),
+        ],
+        [
+            State("input-data", "data"),
+            State("map-input-data", "data"),
+            State("candlestick-input-data", "data"),
+            State("treemap-input-data", "data"),
         ],
-        [State("input-data", "data"), State("map-input-data", "data")],
     )
-    def main_input_class(ts_, ts2_, inputs, map_inputs):
-        return main_inputs_and_group_val_display(dict_merge(inputs, map_inputs))
+    def main_input_class(
+        ts_, ts2_, _ts3, _ts4, inputs, map_inputs, cs_inputs, treemap_inputs
+    ):
+        return main_inputs_and_group_val_display(
+            dict_merge(inputs, map_inputs, cs_inputs, treemap_inputs)
+        )
 
     @dash_app.callback(
         [
@@ -674,6 +813,8 @@ def init_callbacks(dash_app):
             Input("chart-tabs", "value"),
             Input("group-dropdown", "value"),
             Input("map-group-dropdown", "value"),
+            Input("candlestick-group-dropdown", "value"),
+            Input("treemap-group-dropdown", "value"),
         ],
         [
             State("url", "pathname"),
@@ -682,9 +823,23 @@ def init_callbacks(dash_app):
         ],
     )
     def group_values(
-        chart_type, group_cols, map_group_cols, pathname, inputs, prev_group_vals
+        chart_type,
+        group_cols,
+        map_group_cols,
+        cs_group_cols,
+        treemap_group_cols,
+        pathname,
+        inputs,
+        prev_group_vals,
     ):
-        group_cols = make_list(map_group_cols if chart_type == "maps" else group_cols)
+        group_cols = group_cols
+        if chart_type == "maps":
+            group_cols = map_group_cols
+        elif chart_type == "candlestick":
+            group_cols = cs_group_cols
+        elif chart_type == "treemap":
+            group_cols = treemap_group_cols
+        group_cols = make_list(group_cols)
         if not show_group_input(inputs, group_cols):
             return [], None
         data_id = get_data_id(pathname)
@@ -700,7 +855,6 @@ def init_callbacks(dash_app):
             selections = [pgv for pgv in prev_group_vals if pgv in available_vals]
         if not len(selections) and len(group_vals) <= MAX_GROUPS:
             selections = available_vals
-
         return group_vals, selections
 
     @dash_app.callback(
@@ -721,3 +875,5 @@ def init_callbacks(dash_app):
         return charts_layout(df, settings, **params)
 
     custom_geojson.init_callbacks(dash_app)
+    drilldown_modal.init_callbacks(dash_app)
+    lock_zoom.init_callbacks(dash_app)
