@@ -1,7 +1,11 @@
 import string
 
 from six import PY3
-from collections import MutableMapping
+
+try:
+    from collections.abc import MutableMapping
+except ImportError:
+    from collections import MutableMapping
 
 DATA = {}
 DATASETS = {}
@@ -182,6 +186,16 @@ def cleanup(data_id=None):
                 del store[data_id]
 
 
+def load_flag(data_id, flag_name, default):
+    import dtale
+
+    curr_settings = get_settings(data_id) or {}
+    global_flag = getattr(dtale, flag_name.upper())
+    if global_flag != default:
+        return global_flag
+    return curr_settings.get(flag_name, default)
+
+
 def _as_dict(store):
     """Return the dict representation of a data store.
     Stores must either be an instance of MutableMapping OR have a to_dict method.
