@@ -195,7 +195,9 @@ def json_string(x, nan_display="", **kwargs):
     :return: string value
     :rtype: str
     """
-    if x or x in [False, 0]:
+    if pd.isnull(x):
+        return nan_display
+    if x or x in ["", False, 0]:
         try:
             return str(x)
         except UnicodeEncodeError:
@@ -294,7 +296,7 @@ def json_timestamp(x, nan_display="", **kwargs):
             (time.mktime(output.timetuple()) + (old_div(output.microsecond, 1000000.0)))
             * 1000
         )
-        return output
+        return str(output) if kwargs.get("as_string", False) else output
     except BaseException:
         return nan_display
 
@@ -313,29 +315,41 @@ class JSONFormatter(object):
         >>> jsonify(f.format_dicts([dict(a=1, b=2.0, c='c')]))
     """
 
-    def __init__(self, nan_display=""):
+    def __init__(self, nan_display="", as_string=False):
         self.fmts = []
         self.nan_display = nan_display
+        self.as_string = as_string
 
     def add_string(self, idx, name=None):
-        self.fmts.append([idx, name, json_string])
+        def f(x, nan_display):
+            return json_string(x)
+
+        self.fmts.append([idx, name, f])
 
     def add_int(self, idx, name=None, as_string=False):
         def f(x, nan_display):
-            return json_int(x, nan_display=nan_display, as_string=as_string)
+            return json_int(
+                x, nan_display=nan_display, as_string=as_string or self.as_string
+            )
 
         self.fmts.append([idx, name, f])
 
     def add_float(self, idx, name=None, precision=6, as_string=False):
         def f(x, nan_display):
             return json_float(
-                x, precision, nan_display=nan_display, as_string=as_string
+                x,
+                precision,
+                nan_display=nan_display,
+                as_string=as_string or self.as_string,
             )
 
         self.fmts.append([idx, name, f])
 
-    def add_timestamp(self, idx, name=None):
-        self.fmts.append([idx, name, json_timestamp])
+    def add_timestamp(self, idx, name=None, as_string=False):
+        def f(x, nan_display):
+            return json_timestamp(x, as_string=as_string or self.as_string)
+
+        self.fmts.append([idx, name, f])
 
     def add_date(self, idx, name=None, fmt="%Y-%m-%d %H:%M:%S"):
         def f(x, nan_display):
@@ -508,11 +522,11 @@ def find_dtype_formatter(dtype, overrides=None):
     return json_string
 
 
-def grid_formatter(col_types, nan_display="", overrides=None):
+def grid_formatter(col_types, nan_display="", overrides=None, as_string=False):
     """
     Build :class:`dtale.utils.JSONFormatter` from :class:`pandas:pandas.DataFrame`
     """
-    f = JSONFormatter(nan_display)
+    f = JSONFormatter(nan_display, as_string=as_string)
     mappings = dict_merge(DF_MAPPINGS, overrides or {})
     for i, ct in enumerate(col_types, 1):
         c, dtype = map(ct.get, ["name", "dtype"])
@@ -719,7 +733,6 @@ def run_query(df, query, context_vars=None, ignore_empty=False):
 
         inv_replacements = {replacements[k]: k for k in replacements.keys()}
         df = df.rename(columns=replacements)
-
         df = df.query(final_query, local_dict=context_vars or {})
         df = df.rename(columns=inv_replacements)
     else:
@@ -740,6 +753,10 @@ class DuplicateDataError(Exception):
         self.data_id = data_id
 
 
+def triple_quote(val):
+    return '"""{}"""'.format(val)
+
+
 def build_code_export(data_id, imports="import pandas as pd\n\n", query=None):
     """
     Helper function for building a string representing the code that was run to get the data you are viewing to that
@@ -758,6 +775,8 @@ def build_code_export(data_id, imports="import pandas as pd\n\n", query=None):
     ctxt_vars = global_state.get_context_variables(data_id)
 
     startup_code = settings.get("startup_code") or ""
+    if startup_code and not startup_code.endswith("\n"):
+        startup_code += "\n"
     xarray_setup = ""
     if data_id in global_state.DATASETS:
         xarray_dims = global_state.get_dataset_dim(data_id)
@@ -793,7 +812,7 @@ def build_code_export(data_id, imports="import pandas as pd\n\n", query=None):
     if final_query is None:
         final_query = settings.get("query")
 
-    if final_query is not None:
+    if final_query is not None and final_query != "":
         if len(ctxt_vars or {}):
             final_history.append(
                 (
@@ -802,13 +821,17 @@ def build_code_export(data_id, imports="import pandas as pd\n\n", query=None):
                     "\n# DISCLAIMER: running this line in a different process than the one it originated will produce\n"
                     "#             differing results\n"
                     "ctxt_vars = dtale_global_state.get_context_variables('{data_id}')\n\n"
-                    'df = df.query("{query}", local_dict=ctxt_vars)\n'
-                ).format(query=final_query, data_id=data_id)
+                    "df = df.query({query}, local_dict=ctxt_vars)\n"
+                ).format(query=triple_quote(final_query), data_id=data_id)
             )
         else:
-            final_history.append("df = df.query('{}')\n".format(final_query))
-    elif "query" in settings:
-        final_history.append("df = df.query('{}')\n".format(settings["query"]))
+            final_history.append(
+                "df = df.query({})\n".format(triple_quote(final_query))
+            )
+    elif settings.get("query"):
+        final_history.append(
+            "df = df.query({})\n".format(triple_quote(settings["query"]))
+        )
     if "sort" in settings:
         cols, dirs = [], []
         for col, dir in settings["sort"]:
